@@ -18,8 +18,26 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
+#ifndef SEARCHMANAGER_IMPL_H
+#define SEARCHMANAGER_IMPL_H
 
+    
+inline int SearchCounters::totalLinks() const {
+    return total_links_;
+}
 
+inline int SearchCounters::brokenLinks() const {
+    return broken_links_;
+}
+
+inline int SearchCounters::undeterminedLinks() const {
+    return undetermined_links_;
+}
+
+inline SearchCounters const& SearchManager::searchCounters() const
+{
+    return search_counters_;
+}
 
 inline int SearchManager::maximumCurrentConnections() const
 {
@@ -34,18 +52,17 @@ inline SearchManager::SearchMode const& SearchManager::searchMode() const
 
 inline int SearchManager::checkedLinks() const
 {
-    Q_ASSERT(checked_links_ > 0);
-    return checked_links_;
+    Q_ASSERT(search_counters_.total_links_ > 0);
+    return search_counters_.total_links_;
 }
 
-inline QTime SearchManager::timeElapsed() const
+inline void SearchManager::startSearch()
 {
-    int ms = time_.elapsed();
-    //kdDebug(23100) <<  "Time elapsed (ms): " << ms << endl;
-    return QTime(0, 0).addMSecs(ms);
+    Q_ASSERT(root_url_.isValid());
+    startSearch(root_url_);
 }
 
-inline void SearchManager::startSearch(KURL const& root)
+inline void SearchManager::startSearch(KUrl const& root)
 {
     startSearch(root, search_mode_);
 }
@@ -67,7 +84,7 @@ inline void SearchManager::setExternalDomainDepth(int depth)
 
 inline void SearchManager::setDomain(QString const& domain)
 {
-    Q_ASSERT(domain.find("http://") == -1);
+    Q_ASSERT(domain.indexOf("http://") == -1);
     domain_ = domain;
     general_domain_ = generalDomain();
     checked_general_domain_ = true;
@@ -81,6 +98,7 @@ inline void SearchManager::setCheckParentDirs(bool flag)
 inline void SearchManager::setCheckExternalLinks(bool flag)
 {
     check_external_links_ = flag;
+    external_domain_depth_ = check_external_links_ ? 1 : 0;
 }
 
 inline void SearchManager::setCheckRegularExpressions(bool flag)
@@ -90,7 +108,8 @@ inline void SearchManager::setCheckRegularExpressions(bool flag)
 
 inline void SearchManager::setRegularExpression(QString const& reg_exp, bool case_sensitive)
 {
-    reg_exp_ = QRegExp(reg_exp, case_sensitive);
+//     int case = case_sensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
+    reg_exp_ = QRegExp(reg_exp, case_sensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
 }
 
 inline void SearchManager::setTimeOut(int time_out)
@@ -99,6 +118,12 @@ inline void SearchManager::setTimeOut(int time_out)
     time_out_ = time_out;
 }
 
+inline void SearchManager::setRootUrl(KUrl const& url)
+{
+    root_url_ = url;
+}
+
+
 
 
 inline bool SearchManager::checkParentDirs() const
@@ -121,7 +146,7 @@ inline bool SearchManager::searching() const
     return searching_;
 }
 
-inline bool SearchManager::localDomain(KURL const& url, bool restrict) const
+inline bool SearchManager::localDomain(KUrl const& url, bool restrict) const
 {
 	return Url::localDomain(root_.absoluteUrl(), url, restrict);
 }
@@ -141,12 +166,12 @@ inline bool SearchManager::hasDocumentRoot() const
     return has_document_root_;
 }
 
-inline KURL const& SearchManager::documentRoot() const
+inline KUrl const& SearchManager::documentRoot() const
 {
     return document_root_url_;
 }
 
-inline void SearchManager::setDocumentRoot(KURL const& url)
+inline void SearchManager::setDocumentRoot(KUrl const& url)
 {
     Q_ASSERT(url.isValid()); // includes empty URLs
     Q_ASSERT(!url.protocol().startsWith("http"));
@@ -155,4 +180,10 @@ inline void SearchManager::setDocumentRoot(KURL const& url)
     has_document_root_ = true;
 }
 
+inline ThreadWeaver::Weaver* SearchManager::threadWeaver() const
+{
+    return &m_weaver;
+}
 
+
+#endif // SEARCHMANAGER_IMPL_H
